package de.hft.stuttgart.citydoctor2.gui;

import de.hft.stuttgart.citydoctor2.gui.tree.ZipEntryListCell;
import de.hft.stuttgart.citydoctor2.gui.tree.ZipEntryNode;
import de.hft.stuttgart.citydoctor2.utils.Localization;
import de.hft.stuttgart.citydoctor2.zip.CityGmlZipArchive;
import de.hft.stuttgart.citydoctor2.zip.CityGmlZipEntry;
import de.hft.stuttgart.citydoctor2.zip.ZipEntryErrorType;
import javafx.application.Platform;
import javafx.fxml.FXML;
import javafx.fxml.FXMLLoader;
import javafx.scene.Scene;
import javafx.scene.control.Button;
import javafx.scene.control.Label;
import javafx.scene.control.ListView;
import javafx.scene.control.TextField;
import javafx.scene.control.TitledPane;
import javafx.scene.image.Image;
import javafx.scene.input.KeyCode;
import javafx.scene.input.KeyEvent;
import javafx.scene.layout.VBox;
import javafx.stage.Modality;
import javafx.stage.Stage;
import javafx.stage.Window;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import java.io.IOException;

public class ZipEntryPicker {

    private static final Logger logger = LogManager.getLogger(ZipEntryPicker.class);

    private Stage stage;
    private CityGmlZipArchive archive;

    @FXML
    private TitledPane entriesPane;
    @FXML
    private TitledPane metadataPane;

    @FXML
    private Label subpathLbl;
    @FXML
    private TextField subpathValueTxt;

    @FXML
    private Label erroneousLbl;
    @FXML
    private Label erroneousValue;

    @FXML
    private Label filesizeLbl;
    @FXML
    private Label filesizeValue;

    @FXML
    private Label validatedLbl;
    @FXML
    private Label validatedValue;

    @FXML
    private Label objectCountLbl;
    @FXML
    private Label objectCountValue;

    @FXML
    private Button cancelBtn;
    @FXML
    private Button loadBtn;

    @FXML
    private ListView<ZipEntryNode> entryList;

    private CityDoctorController controller;

    private String unknownValueText = Localization.getText("ZipEntryPicker.unknownValue");

    public ZipEntryPicker(Window parent, CityDoctorController controller) throws IOException {
        FXMLLoader loader = new FXMLLoader(ZipEntryPicker.class.getResource("ZipEntryPicker.fxml"));
        loader.setController(this);
        this.controller = controller;
        archive = controller.getZipArchive();
        VBox box = loader.load();
        this.controller = controller;
        stage = new Stage();
        stage.getIcons().add(new Image(MainWindow.class.getResourceAsStream("icons/CityDoctor-Logo-rot_klein.jpg")));
        stage.setScene(new Scene(box));
        stage.initOwner(parent);
        stage.initModality(Modality.APPLICATION_MODAL);
        stage.setTitle("Zip-Entry Picker");
        stage.getScene().addEventFilter(KeyEvent.KEY_PRESSED, (KeyEvent event) -> {
            if (event.getCode() == KeyCode.ESCAPE) {
                stage.close();
            }
        });
    }

    public void initialize() {
        applyLanguageControls();
        applyLocalization();
    }

    private void applyLocalization() {
        entriesPane.setText(Localization.getText("ZipEntryPicker.entryListTitle"));
        metadataPane.setText(Localization.getText("ZipEntryPicker.metadata"));
        subpathLbl.setText(Localization.getText("ZipEntryPicker.subpathLbl"));
        erroneousLbl.setText(Localization.getText("ZipEntryPicker.erroneousLbl"));
        filesizeLbl.setText(Localization.getText("ZipEntryPicker.filesizeLbl"));
        validatedLbl.setText(Localization.getText("ZipEntryPicker.validatedLbl"));
        objectCountLbl.setText(Localization.getText("ZipEntryPicker.objectCountLbl"));

        subpathValueTxt.setText(unknownValueText);
        erroneousValue.setText(unknownValueText);
        filesizeValue.setText(unknownValueText);
        validatedValue.setText(unknownValueText);
        objectCountValue.setText(unknownValueText);

        loadBtn.setText(Localization.getText("ZipEntryPicker.loadBtn"));
        cancelBtn.setText(Localization.getText("ZipEntryPicker.cancelBtn"));
    }

    private void applyLanguageControls() {

    }
}
